@@ -149,7 +149,7 @@ sub show {
 
 	my $name = $self->{name};
 	printf __("Time: %-20s %.4fs\n"),
-		(defined $name ? $name : 'Unnamed'),
+		(defined $name ? $name : __('Unnamed')),
 		$self->elapsed
 	;
 
@@ -189,10 +189,11 @@ Emmanuel Rodriguez E<lt>potyl@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Emmanuel Rodriguez.
+Copyright (C) 2008,2009 by Emmanuel Rodriguez.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
